Struct rugraph::Graph[][src]

pub struct Graph<T> where
    T: Ord + Clone + Display + Debug
{ /* fields omitted */ }
Graph is actually a generic directed graph where each node of type T must implement: T: Ord + Clone + std::fmt::Display + std::fmt::Debug

Implementations

Adds a new node elem to the graph

Creates a new edge from node from to node to nodes from and to must be previously added to the graph

Returns a vector containing the neighbors of node from

Returns if a node from is connected to a node to

Returns if node to is a neighbord of from

Returns a Vec<Vec<T>> containing all the simple paths from node from to node to

Exports the graph to a dot file. file must be a valid file ready to be written. graph_name is the name of the graph