Struct rugraph::Graph [−][src]
Graph is actually a generic directed graph where each node of type T
must implement: T: Ord + Clone + std::fmt::Display + std::fmt::Debug
Implementations
Creates a new edge from node from to node to
nodes from and to must be previously added to the graph
Returns a vector containing the neighbors of node from
Returns if a node from is connected to a node to
Returns if node to is a neighbord of from
Returns a Vec<Vec<T>> containing all the simple paths
from node from to node to